@@ -1,6 +1,18 @@
+# This library is in Development and bugs can be expected. If you encounter any bugs, want to give feedback, or would like to contribute, join our Discord server.
+# https://discord.gg/TUUbzTa3B7
+
+"""
+Copyright 2021 George Luca
+
+Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+"""
+
 import os
 import discord
-import asyncio
 import datetime
 import aiosqlite
 
@@ -20,11 +32,6 @@ print("""
 ===========================================================================================
 """)
 
-async def reload(bat, dir, client):
-    os.chdir(dir)
-    os.startfile(bat)
-    await client.close()
-
 class admin:
 
     async def mute(ctx, member, *args, role_add=1, role_remove=1, reason=None, **kwargs):
@@ -37,6 +44,8 @@ class admin:
             await ctx.send(embed=embed, delete_after=5)
             return
         else:
+            if not isinstance(ctx.guild.get_role(role_add), discord.Role):
+                return
             await member.add_roles(ctx.guild.get_role(role_add))
             if role_remove != 1:
                 try:
@@ -56,6 +65,8 @@ class admin:
             await ctx.send(embed=embed, delete_after=5)
             return
         else:
+            if not isinstance(ctx.guild.get_role(role_remove), discord.Role):
+                return
             await member.remove_roles(ctx.guild.get_role(role_remove))
             if role_add != 1:
                 try:
@@ -332,6 +343,8 @@ class mute_on_join:
         user = member
         guildid = str(member.guild.id)
         muted_role = member.guild.get_role(role)
+        if not isinstance(muted_role, discord.Role):
+            return
         os.chdir(dir)
         member = str(member.id)
         try:
@@ -584,20 +597,18 @@ class warnings:
                                     await db.commit()
                                     return
                                 if "d" in time:
-                                    time = int(time[:-1])*86400
+                                    time = int(time[:-1])
                                     await member.ban(reason=message)
                                     time = datetime.datetime.now() + datetime.timedelta(days=time)
                                     await db.execute("INSERT INTO tempban (guild,member,time) VALUES (?,?,?)", (guild,memberid,time))
                                     await db.commit()
                                     return
                             else:
-                                try:
-                                    add_role = ctx.guild.get_role(add_role)
-                                except:
+                                add_role = ctx.guild.get_role(add_role)
+                                if not isinstance(add_role, discord.Role):
                                     return
-                                try:
-                                    remove_role = ctx.guild.get_role(remove_role)
-                                except:
+                                remove_role = ctx.guild.get_role(remove_role)
+                                if not isinstance(remove_role, discord.Role):
                                     remove_role = None
                                 if remove_role != None:
                                     if add_role in member.roles:
@@ -681,8 +692,11 @@ class warnings:
                                 return
                             if warnings_number_str == "mute":
                                 add_role = ctx.guild.get_role(add_role)
-                                if remove_role != None:
+                                try:
                                     remove_role = ctx.guild.get_role(remove_role)
+                                except:
+                                    remove_role = None
+                                if remove_role != None:
                                     if add_role in member.roles:
                                         return
                                     else:
@@ -692,6 +706,7 @@ class warnings:
                                 else:
                                     await member.add_roles(add_role)
                                     await mute_on_join.mute_add(ctx.guild, member, dir)
+                                    
     async def temp_mute_loop(dir, bot):
         os.chdir(dir)
         async with aiosqlite.connect("warnings.db") as db:
@@ -703,9 +718,9 @@ class warnings:
                             guild = bot.get_guild(int(guild))
                             member = guild.get_member(int(member))
                             time = datetime.datetime.fromisoformat(time_str)
-                            role_add = await db.execute("SELECT role_add FROM mute_role_info WHERE guild = ?", (str(guild.id),))
+                            role_add = await db.execute("SELECT role_add FROM mute_roles_info WHERE guild = ?", (str(guild.id),))
                             role_add = await role_add.fetchone()
-                            role_remove = await db.execute("SELECT role_remove FROM mute_role_info WHERE guild = ?", (str(guild.id),))
+                            role_remove = await db.execute("SELECT role_remove FROM mute_roles_info WHERE guild = ?", (str(guild.id),))
                             role_remove = await role_remove.fetchone()
                             if datetime.datetime.now() >= time:
                                 if role_remove != "None" and role_remove != "none":
